import React from 'react';
import {
  StyleSheet,
  Text,
  View,
  Button,
  ActionSheetIOS
} from 'react-native';

import {
  ActionSheet,
  ActionSheetTitle,
  ActionSheetContent,
  ActionSheetItem,
  ActionSheetSubmitButton
} from 'react-native-alerts-and-pickers'

import { Ionicons } from '@expo/vector-icons';

export default class App extends React.Component {
  state = {
    default: false,
    custom: false,
    withSubtitles: false
  }

  toggle = (key, value = true) => {
    this.setState({ [key]: value })
  }

  render () {
    return (
      <View style={styles.container}>
        <Button title="Open" onPress={this.toggle.bind(this, 'default', true)} />
        <Button title="Custom colors" onPress={this.toggle.bind(this, 'custom', true)} />
        <Button title="Custom colors and icons" onPress={this.toggle.bind(this, 'customIcons', true)} />
        <Button title="With subtitles and not cancellable" onPress={this.toggle.bind(this, 'withSubtitles', true)} />
        <ActionSheet
          cancelable
          show={this.state.default}
          onRequestClose={this.toggle.bind(this, 'default', false)}
        >
          <ActionSheetContent>
            <ActionSheetItem
              title="Lorem ipsum"
              onPress={this.toggle.bind(this, 'default', false)}
            />
            <ActionSheetItem
              title="Lipsum dolor"
              onPress={this.toggle.bind(this, 'default', false)}
            />
          </ActionSheetContent>
          <ActionSheetSubmitButton
            label="Cancel"
            onPress={this.toggle.bind(this, 'default', false)}
          />
        </ActionSheet>
        <ActionSheet
          cancelable
          show={this.state.customIcons}
          onRequestClose={this.toggle.bind(this, 'customIcons', false)}
        >
          <ActionSheetContent>
            <ActionSheetItem
              title="Camera"
              align="flex-start"
              tintColor="#3D3D3D"
              iconComponent={
                <Ionicons name="ios-camera-outline" size={32} color="#007AFF" />
              }
              onPress={this.toggle.bind(this, 'customIcons', false)}
            />
            <ActionSheetItem
              title="Photo & Video Library"
              align="flex-start"
              tintColor="#3D3D3D"
              iconComponent={
                <Ionicons name="ios-image" size={32} color="#007AFF" />
              }
              onPress={this.toggle.bind(this, 'customIcons', false)}
            />
            <ActionSheetItem
              title="Location"
              align="flex-start"
              tintColor="#3D3D3D"
              iconComponent={
                <Ionicons name="ios-navigate" size={32} color="#007AFF" />
              }
              onPress={this.toggle.bind(this, 'customIcons', false)}
            />
            <ActionSheetItem
              title="Contact"
              align="flex-start"
              tintColor="#3D3D3D"
              iconComponent={
                <Ionicons name="ios-contact" size={32} color="#007AFF" />
              }
              onPress={this.toggle.bind(this, 'customIcons', false)}
            />
          </ActionSheetContent>
          <ActionSheetSubmitButton
            label="Cancel"
            onPress={this.toggle.bind(this, 'customIcons', false)}
          />
        </ActionSheet>

        <ActionSheet
          cancelable
          show={this.state.custom}
          onRequestClose={this.toggle.bind(this, 'custom', false)}
        >
          <ActionSheetContent>
            <ActionSheetItem
              title="Lorem ipsum"
              tintColor="green"
              onPress={this.toggle.bind(this, 'custom', false)}
            />
            <ActionSheetItem
              title="Lipsum dolor"
              tintColor="#333"
              onPress={this.toggle.bind(this, 'custom', false)}
            />
          </ActionSheetContent>
          <ActionSheetSubmitButton
            label="Cancel"
            onPress={this.toggle.bind(this, 'custom', false)}
          />
        </ActionSheet>
        <ActionSheet
          cancellable={false}
          show={this.state.withSubtitles}
          onRequestClose={this.toggle.bind(this, 'withSubtitles', false)}
        >
          <ActionSheetContent>
            <ActionSheetItem
              title="Other passwords..."
              onPress={this.toggle.bind(this, 'withSubtitles', false)}
            />
            <ActionSheetItem
              title="Forget Saved Password"
              subtitle="for rafaelmotta021@gmail.com"
              destructive
              onPress={this.toggle.bind(this, 'withSubtitles', false)}
            />
          </ActionSheetContent>
          <ActionSheetSubmitButton
            label="Cancel"
            onPress={this.toggle.bind(this, 'withSubtitles', false)}
          />
        </ActionSheet>
      </View>
    )
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
    justifyContent: 'center',
  },
});
